@@ -11,13 +11,6 @@ from argparse import ArgumentParser
 import MySQLdb as mysql
 
 
-
-__author__ = "Cyprien Devillez"
-__license__ = "GPL"
-__version__ = "0.0.6"
-__description__ = """ Simple CLI tool to create and delete easily MySQL databases. """
-
-
 def query_yes_no(question, default="yes"):
     valid = {"yes":True,   "y":True,  "ye":True,
              "no":False,     "n":False}
@@ -200,7 +193,7 @@ class mysqlrocket:
 def launcher():
 	parser = ArgumentParser(description=__description__,prog="mysqlrocket")
 
-	parser.add_argument("-v", "--version",  action="version",   version="%(prog)s : "+__version__ ,help="Show program version.")
+	parser.add_argument("-v", "--version",  action="version",   version="%(prog)s : "+VERSION ,help="Show program version.")
 	parser.add_argument('-u', type=str, default='root', help='mysql user')
 	parser.add_argument('-H', type=str, default='localhost', help='mysql host')
 	parser.add_argument('-p', type=str, default='', help='mysql password')
